@@ -5,6 +5,7 @@ require 'digest/sha1'
 require 'date'
 require 'thread'
 require 'timeout'
+require 'stringio'
 require 'yaml'
 
 require 'json-schema/schema/reader'
@@ -299,7 +300,6 @@ module JSON
 
       def clear_cache
         @@schemas = {}
-        JSON::Util::URI.clear_cache
       end
 
       def schemas
